DOSBox v0.74-2 Manual (brug altid den sidste nye version fra www.dosbox.com)


======
NOTAT: 
======

Selvom Vi håber at DOSBOX en dag vil kunne køre alle programmer der
nogensinde er lavet til PCen, er vi der ikke endnu. 
Lige nu er DOSBox, der kører på en high-end maskine, nogenlunde lig med en 
Pentium I PC.
 DOSBox Kan indstilles til at køre en bred vifte af DOS spil, fra
CGA/Tandy/PCjr klassikere til spil fra Quake æraen.



======
INDEX:
======
1. Hurtigstart
2. FAQ (Ofte Stillede Spørgsmål)
3. Kommandolinie Parametre
4. Interne Programmer
5. Specielle taster
6. Joystick/Gamepad
7. KeyMapper (Tastatur og joystick indstillinger)
8. Tastatur Layout
9. Serial Multiplayer feature
10. Hvordan du ændrer hastigheden på DOSBox
11. Problemløsning
12. DOSBOX's statusvindue
13. Config-filen (indstillingsfilen)
14. Sprog-filen
15. Hvordan du bygger din egen version af DOSBox
16. Special thanks
17. Kontakt



===============
1. Hurtigstart:
===============

 For en hurtig introduktion, skriv INTRO i DOSBox.
Det er vigtigt at du bliver dus med det at montere(mount-kommandoen),
DOSBox gør ikke selv automatisk drev(ene) (eller dele af drev(ene)), 
tilgængelige for emuleringen. 
Se FAQ : "Kom igang", og beskrivelsen af MOUNT kommandoen 
og beskrivelsen af Mount kommandoen (sektion 4 "Interne Programmer"). Hvis du har
et spil på cdrom, 
kan du evt. prøve denne guide: https://www.vogons.org/viewtopic.php?t=8933

 



=======
2. FAQ:
=======

KOM IGANG:      Hvordan starter man?
AUTOMATISERING: Skal jeg altid skrive disse "mount" kommandoer?
FULDSKÆRM:      Hvordan skifter jeg til fuldskærm?
FULDSKÆRM:      Fuldskærm-indstillingen er for stor.
CD-ROM:         Min CD-ROM virker ikke.
CD-ROM:         Spillet/Programmet kan ikke finde sin CD-ROM.
MUS:            Musen Virker Ikke
LYD:            Der er Ingen Lyd.
LYD:            Hvilken Lyd-hardware understøtter DOSBox ikke/endnu? 
LYD:            Lyden hakker eller lyder forlænget/mærkelig.
TASTATUR:       Jeg kan ikke skrive \ eller : i DOSBox.
TASTATUR:       Højre skift og "\" Virker ikke i DOSBOx.  
TASTATUR:       Tastaturet hakker.
KONTROL:        Figuren/cursoren bevæger sig altid i een retning!
HASTIGHED:      Spillet/Programmet kører for langsomt/for hurtigt!
NEDBRUD:        Spillet/Programmet kører overhovedet ikke/bryder ned!  
NEDBRUD:        DOSBox bryder ned ved opstart!
SPIL:           Mit Build spil(Duke3D/Blood/Shadow Warrior) har problemer.
SIKKERHED:      Kan DOSBox skade min Computer?
Indstillinger:  Jeg vil gerne ændre DOSBox's indstillinger.   
HJÆLP:          God manual, men jeg forstår det stadig ikke.



START: Kom igang?
    Til at begynde med har du et Z:\ istedet for C:\ ved prompten.
    Du kan gøre dine mapper/directories/biblioteker brugbare som drev i DOSBox
    ved hjælp af "mount" kommandoen. F. eks. vil, i Windows, kommandoen 
    "mount C D:\GAMES" give dig et C drev i DOSBox som peger mod din Windows 
    D:\GAMES Mappe (oprettet tidligere).
    I Linux, vil "mount c /home/username" give dig et C drev i DOSBox som
    peger mod /home/username i Linux.
    Skriv "C:" for at skifte til det førnævnte monterede drev. Hvis Alting gik 
    godt, vil DOSBox vil vise prompten "C:\>". 


AUTOMATISERING: Skal jeg altid udføre disse kommandoer?
    Der er i DOSBox's config-fil en [autoexec] sektion. Kommandoerne som er 
    skrevet der køres når DOSBox startes, så du kan bruge denne sektion til at 
    montere. Se sektion 13. Config-filen (indstillingsfilen) 



FULDSKÆRM: Hvordan ændrer jeg til fuldskærm modus?
    Pres alt-enter. Alternativt: Tilret DOSBox's config-fil og ændr indstillingen   
    fullscreen=false til fullscreen=true. Leg med indstilligen: fullresolution hvis
    fuldskærms modus ser forkert ud efter din mening. Pres alt-enter igen for at 
    komme tilbage fra fuldskærms modus. 


FULDSKÆRM: Fuldskærms-indstillingen er for stor.
    Dette kan være et problem i Windows 10, hvis du har display skaléring
    sat til en værdipå over 100%, windows vil isåfald skalere yderligere,
    udover DOSBox's skalering, hvilket kan ske for følgende output: ddraw,
    opengl, openglnb, overlay. Du kan slå denne "Windows opførsel" fra,
    ved at bruge en speciel compatibilitetsindstilling:
    - Højreklik på DOSBox ikonet, og vælg "Egenskaber".
    - Gå til "Kompatibilitet"-fanebladet.
    - Klik på "Ændr Høj DPI indstilling"
    - Markér "Ændr Høj DPI Skalérings Opførsel" Og sæt værdien til "Programmet".
    - Tilføj ændringer, ved at klikke på "OK".

    Denne kompatibilitetsindstilling, er desværre skyld i nogle sideeffekter i
    Vinduetilstand, hvor du bliver nødt til at  ændre opløsningen for windowsresolution
    i konfigurationsfilen-filen (f.eks. windowresolution=1024x768).

    Alternativt kan du slå displayskaléring fra og eller bruge en lavere 
    fuldskærmsopløsnings-værdi.

CD-ROM: Min CD-ROM virker ikke.
    For at montere din CD-ROM i DOSBox Skal du specificere yderligere nogle mulig-
    heder når du monterer. 
    For at muliggøre den mest grundlæggende CD-ROM understøttelse (inkluderer 
    MSCDEX) :
      - mount d f:\ -t cdrom (Windows)
      - mount d /media/cdrom -t cdrom (Linux) 

    Måske ønsker du måske at bruge et andet CD-ROM interface,
    f.eks hvis CD audio ikke virker:      
    For SDL-understøttelse(inkluderer ikke lav-niveau CD adgang)
      - mount d f:\ -t cdrom -usecd 0 -noioctl
    For understøttelse af ioctl med digital audio extraction for CD audio
    (kun Windows, nyttigt for Vista):
      - mount d f:\ -t cdrom -ioctl_dx
    For understøttelse af ioctl med MCI for CD audio(kun Windows):
      - mount d f:\ -t cdrom -ioctl_mci
    For at tvinge brug af ioctl-only(kun Windows):
      - mount d f:\ -t cdrom -ioctl_dio
    For at muliggøre lav-niveau aspi-understøttelse(win98 med aspi-lag installeret) :
      - mount d f:\ -t cdrom -aspi
    
    Kommandoerne :   - d   drevbogstav du får i DOSBox
                     - f:\ placering af cdrom i din PC.
                     - 0   Nummeret af ´CD-ROM drevet, findes med mount -cd   
                           (bemærk at denne værdi er kun nødvendig når du bruger 
                            SDL til CD audio, ellers ignoreres den)
    Se også næste spørgsmål : Spillet/Programmet kan ikke finde sin CD-ROM.


CD-ROM: Spillet/programmetgamet kan ikke finde sin CD-ROM.
    Vær sikker på at montere din CD-ROM med -t cdrom switchen, dette vil starte
    MSCDEX fladen som DOS spil kræver for at give adgang til CD-ROM.
    Prøv også at tilføje korrekt label/etikét (-label LABEL) til mount kommandoen. 
    Hvor LABEL er CD-ROMens CD-label(volume ID).
    Under Windows kan du specificere -ioctl -aspi eller -noioctl. Se beskrivelse 
    i sektion 4: "Interne Programmer"om deres betydning og deres audio-relaterede
    muligheder -ioctl_dx, ioctl_mci, ioctl_dio.
   
    Prøv at lave et CD-ROM billede/image(helst CUE/BIN), og brug DOSBox's interne 
    IMGMOUNT kommando til at montere billedet. Dette muliggør meget god lav-niveau
    CD-ROM support på alle operativ systemer.


MUS: Musen virker ikke.
    Normalt finder DOSBox ud af om et spil bruger Mus.Når du klikker på skærmen
    (DOSBox vinduet)skulle den låse/bindes, og virke. 
    Ved nogle spil virker dette ikke, så du må selv låse/binde musen, ved at taste
    CTRL-F10. 


LYD: Der er ingen lyd.
    Vær sikker på at lyden er korrekt indstillet i spillet. Dette gøres under 
    installationen eller med et setup/setsound program som følger med spillet. 
    Se først om der er auto-detektion. Hvis der ikker er det, så prøv at vælge
    soundblaster eller soundblaster 16 med default settings : "address=220 irq=7 
    dma=1". Du ønsker måske også at vælge 
    Sound Canvas/SCC/MPU-401/General MIDI/Wave Blaster på address 330 IRQ=2 som 
    musik enhed.
    Parametrene til de emulerede lydkort kan ændres i DOSBox's config-fil.
    Hvis du stadig ikke får nogen lyd kan du sætte core til normal og bruge nogle 
    lavere valgte cycles værdier (F.eks. cycles=2000). Vær også sikker på at din
    lydenhed leverer lyd.
    I visse tilfælde kan det være godt at bruge en anden emuleret lydenhed
    f.eks soundblaster pro(sbtype=sbpro1 i DOSBox's config fil) eller
    gravis ultrasound(gus=true).  


LYD: Hvilken Lyd-hardware emulerer DOSBox lige nu?
    DOSBox emulerer adskillige lyd-enheder:
    - Indbygget PC-højtaler/Buzzer
      Denne emulering inkluderer både tonegeneratoren og flere former for digital 
      lyd gennem den indbyggede højtaler.
    - Creative CMS/Gameblaster
      Dette er Creative Labs(R)'s første kort. Standard config sætter det på 
      adressen 220. Det er slået fra som standard.
    - Tandy 3 voice
      Emuleringen mangler "støj-kanalen", som ikke er særlig godt dokumenteret, og
      er som sådan kun det "et bedre gæt" på lyd nøjagtigheden. Er slået fra 
      som standard.
    - Tandy DAC
      Nogle spil kan kræve at sound blaster emuleringen slås fra(sbtype=none), for 
      at give bedre tandy DAC understøttelse(husk at sætte sbtype tilbage på sb16
      efter brug).
    - Adlib
      Denne emulering er næsten perfekt og inkluderer Adlib's evne til næsten at
       spille "digitized" lyd. Adressen er 220 (og 388).
    - SoundBlaster 16 / SoundBlaster Pro I og II / SoundBlaster I og II.
      Som standard leverer SoundBlaster 16 niveaus 16-bit stereo lyd . Du kan vælge
      en anden SoundBlaster version i DOSBox's indstillinger. AWE32 musik er ikke
      emuleret, da du kan bruge MPU-401 istedet(se nedenunder).  
    - Disney Sound source og Covox Speach Thing
      Bruger printerporten, enheden sender kun digital lyd ud. Placeret på LPT1.
    - Gravis Ultrasound          
      Emuleringen af denne hardware er næsten komplet, selvom midi-funktionerne er 
      udeladt, da der er en MPU-401, emuleret i anden kode. For at få Gravis 
      musik, kan det være nødvendigt at installere Gravis Drivere i selve DOSBox. 
      Er slået fra som standard.
    - MPU-401
      Et midi gennemgangs interface er også emuleret. Denne form for lydudgang 
      virker kun med "udenoms" enhed/emulator.
      Windows XP/Vista/7 og MAC OS har til standard en emulator der er kompatibel
      med: Sound Canvas/SCC/General Standard/General MIDI/Wave Blaster.
      Der skal bruges en anden enhed/emulator til Roland LAPC/CM-32L/MT-32
      kompatabilitet.   


 
LYD: Lyden hakker eller lyder mærkelig.
    Du bruger måské for meget cpu kraft til at holde DOSBox kørende ved den 
    aktuelle hastighed. Du kan nedsætte cycles, skippe frames reducere sampling 
    raten på den pågældende lydenhed (se DOSBox's config-fil) eller mixer-enheden.
    Du kan også forøge prebufferen. Se sektion 13. "Config-filen (indstillingsfilen)" 
    Hvis du bruger cycles=max eller =auto , så vær sikker på at der ingen bag-
    grundsprocesser kører, som forstyrrer! (særligt hvis de bruger harddisken)
    Se også sektion 10. "Hvordan du ændrer hastigheden på DOSBox" 



TASTSTUR: Jeg kan ikke skrive \ eller : i DOSBox.
    Dette er et kendt problem. Det opstår hvis dit keyboard/tastatur layout 
    ikke er har et tilsvarende DOS layout (eller ikke blev genkendt korrekt),
    eller tasterne er forkert tildelt.
    Nogle mulige løsninger:
      1. Brug / istedet for, eller Alt-58 istedet for : og Alt-92 istedet for \.
      2. Lav om på dit DOS tastatur layout (se sektion 8 : Tastatur layout).
      3. Tilføj de kommandoer(extra) som du vil køre i [autoexec]-sektionen 
         i DOSBox's "config-fil".
      4. Åbn config-filen og lav usescancodes=false om til usescancodes=true.
      5. Skift tastatur layout i dit operativsystem.  

     Bemærk at hvis værtslayoutet ikke kan genkendes, eller tastaturlayout er 
     sat til none i DOSBox's config-fil, bruges standard US layout.
     Prøv i såfald tasterne omkring "enter" for \ og prøv skift og tasterne 
     imellem "enter" og "L" for ":" .   



TASTATUR: Højre Skift og "\" virker ikke i DOSBox. (kun Windows)
     Dette forekommer når Windows "tror" at du har mere end ét tastatur tilsluttet,
     fordi du bruger fjernstyrede enheder. tjek det med :
     start cmd.exe
     navigér til DOSBox's programfolder
     skriv set sdl_videodriver=windib og tast enter
     tast dosbox.exe og tast enter
     Hvis det virker som det skal, er det bedre at bruge en af de to løsninger hér:
     https://www.vogons.org/viewtopic.php?t=24072

 
    
TASTATUR: Keyboardet/tastaturet forsinkes.
    Sænk prioritetssindstillingen i DOSBox's config-fil, prøv f.eks. :
    "priority=normal,normal". Du kan også sætte et lavere antal cycles
    (brug fast antal cycles under start f.eks cycles=10000).    



KONTROL: Figuren/markøren bevæger sig altid i en retning!
    Se om det stadig sker hvis du slår joystick emuleringen fra,
    sæt joysticktype=none i [joystick] sektionen i DOSBox's config-fil.
    Du skal måské også prøve at trække stik(ene) ud på dit/dine joystick(s).
    Hvis du ønsker at bruge joystick i spillet, prøv så at sætte timed=false,
    calibrér joysticket(både dit OS og i spillet eller dit spil's setup).  



HASTIGHED: Spillet/Programmet kører for langsomt/for hurtigt!
    Se i sektion 10. "Hvordan du ændrer hastigheden på DOSBox".



NEDBRUD: Spillet/Programmet kører overhovedet ikke/bryder ned!  
    Se sektion 11: "Problemløsning".



NEDBRUD: DOSBox bryder ned ved opstart!
    Se sektion 11: "Problemløsning".


        
SPIL: Mit Build spil(Duke3D/Blood/Shadow Warrior)virker ikke som det skal.
    Prøv først at finde en ændret udgave af spillet. disse giver en
    en bedre spil-oplevelse. For at løse grafik-problemerne som forekommer med
    DOSBox i højere opløsninger. Åbn DOSBox's config-fil find machine=svga_s3
    lav svga_s3 om til vesa_nolfb.
    Ændr memsize=16 til memsize=63



SIKKERHED: Kan DOSBox skade min computer?
    DOSBox kan ikke skade din computer mere et hvilket som helst andet resource
    krævende program. forøgelse af cycles overclocker ikke din fysiske CPU.
    for højt sat cycles har en negativ ydelseseffekt på software der kører i 
    DOSBox. 



Indstillinger:  Jeg vil gerne ændre DOSBox's indstillinger.   
    Se sektion 13. "Config-filen (indstillingsfilen)"



HJÆLP: God manual, men jeg forstår det stadig ikke.
    Læs resten af denne Manual Tag også et kig på guider du kan finde på:
    https://www.vogons.org/viewforum.php?f=53
    DOSBox's wiki https://www.dosbox.com/wiki/
    Forumet: https://www.dosbox.com



==========================
3. Kommandolinie Parametre
==========================

Et overblik over kommandolinie options/mulighederne du kan bruge med DOSBox.
Selvom det, i de fleste tilfælde, er nemmere at bruge DOSBox's config-fil.
Se sektion 13. "Config-filen (indstillingsfilen)"

For at kunne bruge kommando-parametre, skal du:
(windows)  Åbne cmd.exe, eller command.com, eller rette i Genvej/shortcut til 
DOSBox.exe.
(Linux)  Brug konsollen.
(MAX OS X) start terminal.app og navigér til:
           /applications/dosbox.app/contents/macos/dosbox

Mulighederne er brugbare for alle operativ systemer medmindre der står andet
i options beskrivelsen:

dosbox [navn] [-exit] [-c command] [-fullscreen] [-userconf] [-conf congfig-fil] 
       [-lang sprog-fil] [-machine maskinetype] [-noconsole]
       [-startmapper] [-noautoexec] [-securemode] 
       [-scaler scaler | -forcescaler scaler]
       [-version] [-socket socket]
       
       
dosbox -version
dosbox -editconf program
dosbox -opencaptures program
dosbox -printconf
dosbox -eraseconf
dosbox -erasemapper

  name   
        Hvis "navn" er et directory/en mappe/et bibliotek, bliver det/den/det 
        monteret som C: drevet.
        Hvis "navn" er en eksekverbar fil, bliver "navn"s 
        directory/mappe/bibliotek monteret som C: drevet og "navn" eksekveret.
    
  -exit  
        DOSBox lukker sig selv når programmet "navn" afsluttes.

  -c command
        Kører den specificerede kommando før "navn" køres. Der kan specificeres 
        flere kommandoer. Hver kommando starter dog med "-c".
        En kommando kan være et internt program, en DOS kommando eller en 
        eksekverbar fil på et monteret drev.

  -fullscreen
        Starter DOSBox i fuldskærm modus.

  -userconf
        StartER DOSBox MED BRUGER-specifiK config-fil. kan bruges sammen med flere
        -conf parametre, men -userconf indlæses altid først.

  -conf config-fil
        Starer DOSBox med options/muligheder specificeret i "config-fil"(KAN 
        være nødvendig med fuld sti).
        Der kan medtages flere -conf muligheder.
        Se sektion 13 for flere detaljer.

  -lang sprog-fil 
        Start DOSBox med sproget specificeret i "sprog-fil".
        Se sektion 14 for flere detaljer.

  -machine maskinetype
        Sæt DOSBox til at emulere en speciel type maskine. brugbare valg er:
        hercules, cga, ega, pcjr, tandy, svga_s3 (standard) som de andre
        svga chipsets der er nævnt i DOSBox's config-fil.
        både grafikkort og tilgængelige lydkort. svga_s3 tilføjer også vesa-
        emulering. For nogle specielle vga-effekter, kan vælges machine typen 
        vgaonly, bemærk at dette fjerner svga muligheder og kan være (betydelig)
        langsommere på grund af den meget større emuleringsprecission.
        Valget af maskinetype anfægter både grafikkort og tilgængelige lydkort.
        

  -noconsole (Windows Only)
        Start DOSBox uden at vise konsol-vinduet. Output bliver omstillet til
        stdout.txt and stderr.txt
	
  -startmapper
        Få direkte adgang til keymapperen ved opstart. Brugbart hvis du har 
        keyboard/tastatur problemer.

  -noautoexec
        Skipper [autoexec] sektionen af den indlæste config-fil.

  -securemode
        Samme som -noautoexec, men tilføjer config.com -securemode i 
        bunden af AUTOEXEC.BAT (hvilket fjerner ændringer i forhold  til hvordan 
        drevene monteres i selve DOSBox).

  -scaler scaler
        Bruger scaleren angivet med "scaler". Se i DOSBox's config-fil
        hvilke scalere du kan bruge.

  -forcescaler scaler
        Ligesom -scaler parameteren, men prøver at tvinge brugen af
        den specificerede scaler selvom den måské ikke passer.

  -version
        Skriver version information og afslutter. Brugbart for Frontends.

  -editconf program
        Kalder program med config-filen som første parameter.
        Man kan skrive denne kommando mere end en gang. Hvis man gør det
        åbnes andet program, hvis det første fejler.

  -opencaptures program
        Kalder program med captures folderen/directoryet/biblioteket som
        første parameter.
  
  -printconf
        Skriver placeringen af standard config-fil.

  -resetconf
        Fjerner standard config-fil.

  -resetmapper
        Fjerner mapperfilen der bliver brugt af standard config-fil.

  -socket
        Sender sokkel nummer til nullmodem emuléringen. See Section 9:
        "Serial Multiplayer feature."

Note: Hvis navn/kommando/configfil/sprog-fil indeholder mellemrum, skal du sætte
     navn/kommando/configfil/sprog-fil i anførelsestegn("kommando eller filnavn").
     Hvis skal bruge anføreslsetegn inden i anføreslsetegn(sansynligvis med 
     -c og mount): 
     Windows og Os2 brugere kan bruge enkelt anførselstegn inden i almindelige 
     anførselstegn. Andre bør kunne bruge "escaped double quotes"(\") inden
     i lamindelige anførselstegn.
     Windows: -c "mount c 'c:\My folder with DOS games\'"
     Linux: -c "mount c \"/tmp/name with space\""

 
Et noget usædvanligt eksempel, til demonstration (windows):
dosbox.exe D:\folder\file.exe -c "MOUNT Y H:\MyFolder"
  Dette monterer D:\folder as C:\ and runs file.exe.
  men før den gør dette monteres H:\MyFolder som Y drevet.

I Windows kan du også trække foldere/filer hen på DOSBox.exe (ell. på genvej til).



=======================
4. Interne Programmmer:
=======================

DOSBox understøtter de fleste DOS kommandoer der bruges i command.com.
Du kan skrive "HELP" ved prompten(efterfulgt af enter) for at få en liste over 
de interne kommandoer.

Desuden er de følgende kommandoer tilgængelige: 

MOUNT "Emuleret Drev bogstav" "Rigtige Drev eller Folder" 
      [-t type] [-aspi] [-ioctl] [-noioctl] [-usecd nummer] [-size drevstørrelse] 
      [-label drevlabel] [-freesize størrelse_i_mb]
      [-freesize størrelse_i_kb (floppies)]  
MOUNT -cd
MOUNT -u "Emuleret Drev Bogstav"

  Program til at montere lokale directories/mapper/biblioteker som drev i DOSBox.

  "Emuleret Drev Bogstav"
        Drev Bogstavet i DOSBox (f.eks. C).

  "Rigtige Drev bogstav (normalt for CD-ROMMer i Windows) eller Folder"
        Det/den lokale directory/mappe/bibliotek du ønsker at tilgængeligt i DOSBox.

  -t type
        Type af monteret directory. følgende kan bruges: dir (default),
        floppy, cdrom.

  -size drevstørrelse     
        Sætter størrelsen på drevet, hvor drevstørrelse er angivet i :
        "bps,spc,tcl,fcl":
           bps: bytes pr sektor, default 512 for regulære drev og
                2048 for CD-ROM drev
           spc: sektorer pr klynge, normalt mellem 1 and 127
           tcl: total klynger, mellem 1 and 65534
           fcl: total frie klynger, mellem 1 og tcl

  -freesize størrelse_i_mb | størrelse_i_kb
        Sætter mængden af fri plads på drev i megabytes.
        (regulære drev) eller kilobytes  (floppy drev).
        Dette er en simplere version af -size.	

  -label drevlabel
        Sætter navnet på drevet til "drevlabel". Er nødvendigt på nogle systemer
        hvis CD'ens label ikke bliver læst korrekt (Værdifuldt når et program 
        ikke kan finde sin CDROM). Hvis du ikke specificerer en/et label og der
        ikke er valgt lav-niveau understøttelse (-usecd # og/eller -ioctl/-aspi
        /-noioctl): 
          Windows: label bliver hentet fra "Rigtige Drev".
          Linux: label bliver sat til NO_LABEL.

        Hvis du specificerer en/et label, vil den/dette label vare lige så længe
        som drevet er monteret. Det vil ikke blive opdateret !!

  -aspi
        Tvinger brugen af aspi-lag. Kun brugbar hvis cdrom monteres under 
        Windows systemer med ASPI-Lag.

  -ioctl (automatisk valg af CD audio interface)
  -ioctl_dx (der bruges digital audio extraction til CD audio)
  -ioctl_dio (ioctl kald bruges til CD audio)
  -ioctl_mci (MCI bruges til CD audio)
        Tvinger brug af ioctl kommandoer, kan kun bruges til at montere CD-ROM
        på et Windows OS som understøtter dem (Win2000/XP/NT).
        De forskellige valg er kun forskellige i måden CD-Audio håndtéres,
        bedste valg kan være -ioctl_dio(mindst resourcekrævende), men virker
        det ikke, kan -ioctl_dx (eller -ioctl_mci) bruges.
   
  -noioctl   
        Tvinger brug af SDL CD-ROM laget. Brugbart til alle systemer.

  -usecd nummer
        Kan bruges på alle systemer, under Windows skal -noioctl switchen være
        tilstede for at kunne bruge -usecd switchen. 
        Gør det muligt at vælge drevet, SDL skal bruge. Brug det hvis det forkerte 
        eller ingen CDROM-drev bliver monteret når du bruger SDL CDROM interfacet.
        "nummer" kan findes med kommandoen "MOUNT -cd". 
      
  -cd
        Viser alle SDL-fundne cdrom drev og deres numre Bruges sammen med -usecd.
        Se informationen under -usecd ovenover. 
  -u
        Fjerner monteringen. Virker ikke for Z:\.

  Note: Det er muligt at montere lokalt directory/mappe/bibliotek som cdrom drev. 
        i så fald er der ingen Hardware Understøttelse.

  I bund og grund tillader MOUNT dig at montere reel hardware til DOSBox's emu-
  leret PC.
  Så MOUNT C C:\Dosspil får DOSBox til at bruge din  C:\Dosspil Folder som C:
  i DOSBox. I DOSBox vil MOUNT C E:\EnFOlder lade DOSBox bruge E:\EnFolder som 
  drev C: i DOSBox.

  Det er ikke anbefalet at Montere hele C drevet med MOUNT C C:\ Det samme gælder
  for at montere roden et andet drev, bortset fra CD-ROMer (grundet af deres ikke- 
  skrivebare natur). Eller du eller DOSBox kan lave fejl - så du risikerer at 
  miste alle dine filer. Lad også være med at Montere "Windows" eller "Programmer"
   eller deres under-foldere i Windows Vista/7 , da det kan forhindre DOSBox i at 
  virke korrekt, eller virke korrekt senere. Det anbefales at have alle spil/
  programmer i en simpel folder, f.eks c:\Dosspil(eller underfoldere til) og 
  så montere den.


  Du bør altid installere dit spil I DOSBox
  Så hvis du har CD'en bør du altid(selv efter installation) montere både 
  Folderen som harddisk og CDROMMEN.
  Harddisk bør monteres som c
    CDROM bør monteres som  d
    Floppy bør monteres som a (ell. b)

  Generelle MOUNT Eksempler (windows):

  1. At montere Folder som Harddiskdrev :
          mount c d:\Dosspil

  3. At montere dit CDROM drev E som cdrom drev D i DOSBox:
          mount d e:\ -t cdrom

  2. At montere a: som diskette : 
          mount a a:\ -t floppy
  
  Avancerede monteringseksempler (windows):

  4. At montere et drev med 870 mb fri diskplads (simpel version):
          mount c d:\Dosspil -freesize 870


  5. At montere et drev med 870 mb free diskspace (kun eksperter, fuld kontrol):
          mount c d:\Dosspil -size 512,127,16513,13500

  1. At montere c:\Dosspil\floppy som diskette : 
          mount a c:\Dosspil\floppy -t floppy


  Andre monteringseksempler:

  3. At montere system cdrom drev på mountpoint /media/cdrom som cdrom drev D 
     i DOSBox:
          mount d /media/cdrom -t cdrom -usecd 0

  6. At montere /home/user/Dosspil som drev C in DOSBox:
          mount c /home/user/Dosspil

  7. At montere Mappe hvor DOSBox blev startet som D i DOSBox:
     mount d .
     (læg mærke til . som repræsenter mappen hvor DOSBox blev startet)  

  Hvis du ønsker at montere et cd-billede/image, prøv IMGMOUNT.
  Mount virker også med cd-billeder/images, men kun hvis du bruger 
  eksterne programmer f.eks. (begge er gratis):
  - Daemon Tools Lite (til CD billeder/images),
  - Virtual Floppy Drive (til floppy images).
  Selvom IMGMOUNT skulle give en bedre kompatabilitet.


MEM
  Program til at vise størrelsen på fri hukommelse.


VER
VER set hoved_version [under_version]
  Viser nuværende DOSBox version og raporteret DOS version
  (uden parameter).
  Ændrer den raporterede DOS version med "set" parameteren,
  f.eks: "VER set 6 22" for at få DOSBox til at raportere DOS 6.22
  som version nummer.


CONFIG -writeconf lokal-fil
CONFIG -writelang lokal-fil
CONFIG -securemode
CONFIG -set "sektion egenskab=værdi"
CONFIG -get "sektion egenskab"

  CONFIG kan bruges til at ændre eller forespørge forskellige indstillinger i 
  DOSBox under brug. CONFIG kan gemme "nuværende indstillinger" og "sprogstrenge"
  til disken(f.eks generere en dansk dosbox.conf). CONFIG Information om alle 
  mulige sektioner kan findes i sektion 13: "Config-filen (indstillingsfilen)".

  -writeconf lokal-fil
       Skriver de nuværende indstillinger til fil. "lokal-fil" er lokaliseret på 
       det lokale drev ikke på et monteret drev i DOSBox. 
       CONFIG-filen kontrollerer forskellige DOSBox-indstillinger : 
       størrelsen på emuleret hukommelse, de emulerede lydkortog mange andre ting
       CONFIG-filen giver dig også adgang til AUTOEXEC.BAT.
       Se gerne sektion 13. "Config-filen (indstillingsfilen)".

  -writelang lokal-fil
       Skriver de nuværende sprog-indstillinger til fil. "lokal-fil" er lokali-
       seret på det lokale drev ikke på et monteret drev i DOSBox. 
       Sprog-filen kontrolerer alle synlige output fra de interne kommandoer og
       den interne DOS.
       Se gerne sektion 14 "sprog-filen".
  
  -securemode
       Skifter DOSBox til mere sikker modus. I dette modus virker de interne
       kommandoer MOUNT, IMGMOUNT and BOOT ikke. Det er heller ikke muligt at 
       kreere en ny config-fil eller language-fil i dette modus.
       (Advarsel: du kan kun afslutte dette modus ved at genstarte DOSBox.)

  -set "sektion egenskab=værdi"
       CONFIG vil prøve at sætte pågældende egenskab til en ny værdi. Lige nu
       kan CONFIG ikke fortælle om kommandoen lykkedes eller ikke.

  -get "sektion egenskab"
       Nuværende værdi af pægældende egenskab skrives og gemmes i miljø-variablen 
       %CONFIG%.Denne kan bruges til at gemme værdien når man bruger batch filer.

  Både "-set" og "-get" virker fra batch filer og kan bruges til at generere egne
  indstillinger for hvert spil. Det er dog måske lettere at bruge forskellige
  DOSBox config-filer.
  
  Eksempler:
  1. At lave  en config-fil i nuværende i din c:\Dosspil folder:
      config -writeconf c:\dosspil\dosbox.conf
  2. At sætte cpu cycles til 10000:
      config -set "cpu cycles=10000"
  3. At afbryde ems hukommelses emulering:
      config -set "dos ems=off"
  4. At se hvilken cpu core/kerne der bruges.
      config -get "cpu core"


LOADFIX [-størrelse] [program] [program-parameters]
LOADFIX -f
  Program til at reducere mængden af fri hukommelse. Brugbar til gamle
  programmer der ikke forventer meget fri hukommelse. 

  -size	        
        antal kilobytes at "æde op", default = 64kb
  
  -f
        frigør alt tidligere allokeret hukommelse
  

Eksempler:
  1. At starte mm2.exe og allokere 64kb hukommelse 
     (mm2 will have 64 kb less available) :
     loadfix mm2
  2. At starte mm2.exe og allokere 32kb hukommelse :
     loadfix -32 mm2
  3. At frigøre tidligere allokeret hukommelse :
     loadfix -f


RESCAN
  Får DOSBox til at genindlæse directory/mappe/biblioteks strukturen. Brugbar 
  hvis du har ændret noget, på et monteret drev, udenfor DOSBox. (CTRL-F4 gør også
  dette!)
  

MIXER
  Får DOSBox til at vise nuværende lydindstillinger. 
  Her er mulighederne for at ændre dem:
  
  mixer channel left:right [/NOSHOW] [/LISTMIDI]
  
  channel
      Kan være : MASTER, DISNEY, SPKR, GUS, SB, FM,  [, CDAUDIO].
      CDAUDIO er kun tilgængeligt hvis et CDROM interface med volume  kontrol
      er muliggjort (CD image, ioctl_dx). 

  left:right
      Lydniveauet i procent. Hvis du sætter D foran ændres det til 
      decibell (eksempel mixer gus d-10).
  
  /NOSHOW
      Forhindrer DOSBox  i at vise resultatet hvis du sætter et lydniveau.

  /LISTMIDI
      Skriver en liste over tilgængelige midi enheder på din pc (Windows). 
      Du kan vælge en anden enhed end Windows default midi-mapper, ved at ændre
      linien 'midiconfig=' [midi] sektionen i Config-filen, til 
      'midiconfig=id', hvor 'id' er nummeret på enheden fra listen genereret af 
      LISTMIDI f.eks midiconfig=2.

      Dette virker ikke i Linux, men du kan nå tilsvarende resultat(er) ved at
      bruge 'pmidi -l' i konsol. Så ændre linien 'midiconfig=' til 
      'midiconfig=port', hvor 'port' er porten for enheden listet med 'pmidi -l'.
       f.eks. midiconfig=128:0 


IMGMOUNT
  Et program til at montere disk images og CD-ROM images i DOSBox (f.eks. en iso).
  
  IMGMOUNT DREV [imagefil] -t [image_type] -fs [image_format] 
            -size [sectorsbytesize, sectorsperhead, heads, cylinders]
  IMGMOUNT DREV [imagefile1, .. ,imagefileN] -t iso -fs iso 

  imagefil
      Placering af image-fil der skal monteres i DOSBox. Placeringen kan være på 
      et monteret drev i DOSBox, eller på din fysiske disk. Det er også muligt at
      montere CD-ROM-billeder (ISOer eller CUE/BIN), Hvis du har brug for at kunne 
      "skifte cd" skal du skrive alle images i rækkefølge 
      (se næste indgang)
   
      CUE/BIN sæt, er de foretrukne CD-ROM images da de kan indeholde lydspor,
      modsat ISOer (som kun kan indeholde data-spor). Når du skal 
	      montere CUE/BIN, skal du altid bruge .CUE-filen

  imagefile1, .. ,imagefileN
      Placeringen af image-filer der skal monteres i DOSBox. At specificere et 
      antal image-filer er kun tilladt for CD-ROM images. CD'erne kan 
      skiftes med CTRL-F4 til enhver tid. Dette er nødvendigt med spil som bruger
      flere CD-ROMMER og kræver at CD'en bliver skiftet undervejs i spillet.
   
  -t 
      Følgende er godkendte image typer:
        floppy: Specificerer et eller flere floppy image(s).  DOSBox finder selv 
                diskens geometri (360K, 1.2MB, 720K, 1.44MB, osv.).
        cdrom:  Specificerer et CD-ROM iso image.  Geometrien bliver sat automa-
                tisk. Kan være en iso eller cue/bin.
        hdd:    Specificerer et harddisk image. Den brugelige CHS geometri skal
                skrives for at det virker.

  -fs 
      Følgende er brugbare filsystem formater:
        iso:  Specificerer ISO 9660 CD-ROM formatet.
        fat:  Specificerer at billedet bruger FAT filsystemet. DOSBox vil forsøge
              at montere dette image som et drev i DOSBox og gøre filerne tilgængelige 
              i DOSBox.
        none: DOSBox Gør ikke noget forsøg på at læse filsystemet på disken.
              Dette bruges hvis hvis du skal formatere den eller starte den med med 
              BOOT kommandoen.  Når du bruger "none" filsystem, er det bedre at
              specificere drevnummer (2 eller 3, 
               2 = master, 3 = slave) end et drevbogstav.  
              For eksempel monteres et 70MB image som slave drev, 
              sådan(uden anførelsestegn):
                "imgmount 3 d:\test.img -size 512,63,16,142 -fs none" 
                (uden anførelsestegn)  sammenlignet med en montering for at læse 
                drevet i DOSBox, som ser sådan ud: 
                "imgmount e: d:\test.img -size 512,63,16,142"

  -size 
     Specificering af drevets Cylindre, Heads og Sektorer.
     Er nødvendigt for at montere harddisk drev images.
     
  Et eksempel på hvordan man monterer CD-ROM images (i Linux):
    1. imgmount d /tmp/cdimage1.cue /tmp/cdimage2.cue -t cdrom
  eller(som også virker) 
    2a. mount c /tmp
    2b. imgmount d c:\cdimage1.cue cdimage2.cue -t iso
  (i Windows):
    imgmount d f:\img\CD1.cue f:\img\CD2.cue f:\img\CD3.cue -t cdrom
    imgmount d "g:\img\7th Guest CD1.cue" "g:\img\7th Guest CD2.cue" -t cdrom
  Glem ikke at du også kan bruge MOUNT med image(s), men kun hvis du bruger externe 
  programmer(begge er gratis):
  - Daemon Tools Lite (for CD images),
  - Virtual Floppy Drive (for floppy images).
  Selvom IMGMOUNT kan give bedre kompatabilitet.


BOOT
  Boot starter floppy images eller harddisk images uafhængigt af operativ-
  systemes emuleringen DOSBox tilbyder. Dette tillader dig at spille starter-
  disketter eller starte andre operativsystemer.
  Hvis det valgte emulerede system er PCjr (machine=pcjr) kan boot kommandoen
  bruges til at indlæse PCjr magasiner (.jrc). 

  BOOT [diskimg1.img diskimg2.img .. diskimgN.img] [-l drevbogstav]
  BOOT [cart.jrc]  (PCjr only)

  diskimg1.img diskimg2.img .. diskimgN.img
     Kan være et relativt nummer på diskette/floppy -images, der ønskes monteret
     efter at DOSBox starter(booter) det specificerede drevbogstav.
     du kan taste CTRL-F4 for at skifte fra nuværende disk til næste disk
     på listen. Listen starter forfra efter sidst disk image.

  [-l drevbogstav]
     Denne parameter tillader dig at specificere drevet du vil starte fra.  
     Default er A drevet, floppy drevet. Du kan også starte et harddisk image 
     monteret som master ved at specificere "-l C" uden anførelsestegn, eller
     starte drevet som slave ved at specificere "-l D"
     
   cart.jrc (PCjr only)
     Når emulering af PCjr er slået til, kan man indlæse magasiner med 
     BOOT kommandoen. Der er stadig begrænset understøttelse.


IPX

  For IPX, er det er nødvendigt at muliggøre IPX netværk i DOSBox's Config-fil.

  Al IPX-netværk bliver styret gennem det interne DOSBox program IPXNET. 
  For hjælp til IPX netværk i DOSBox, tast "IPXNET HELP" (uden anførelsestegn),
  så får du en liste over kommandoer og relevant dokumentation. 

  Hvad angår at sætte et netværk op, skal den ene PC være server. Dette sker med 
  kommandoen : "IPXNET STARTSERVER" (uden anførelsestegn) i en kørende DOSBox. 
  Server DOSBox'en tilføjer automatisk sig selv til det virtuelle IPX netværk.
  Du skal taste "IPXNET CONNECT <computer værts name eller IP>" for hver eneste 
  computer som tilføjes det virtuelle IPX netværk, 
  For eksempel, hvis din server er på bob.dosbox.com, skal du taste 
  "IPXNET CONNECT bob.dosbox.com" på hver eneste ikke-server maskine. 
  
  At spille spil der kræver Netbios skal du bruge en fil som hedder NETBIOS.EXE 
  fra Novell. Opret IPX forbindelsen som forklaret ovenover og kør så "netbios.exe". 

  Følgende er en IPXNET kommando reference: 

  IPXNET CONNECT 

     IPXNET CONNECT  åbner forbindelsen til en IPX kanaliseret server, som kører
     på en anden DOSBox maskine. "addresse" parameteren specificerer IP adressen
     eller værtsnavnet på server-PC'en. Du kan også specificere hvilken UDP port
     du vil bruge. Default bruger IPXNET port 213 - den til IPX kanaliseret 
     tildelte IANA port - til sin forbindelse. 

     Syntaxen for IPXNET CONNECT er: 
     IPXNET CONNECT addresse <port> 

  IPXNET DISCONNECT 

     IPXNET DISCONNECT lukker forbindelsen til den IPX kanaliserende server. 

     Syntaxen for IPXNET DISCONNECT er: 
     IPXNET DISCONNECT 

  IPXNET STARTSERVER 

     IPXNET STARTSERVER starter en IPX kanaliserende server på den kørende DOSBox. 
     Standard, vil serveren acceptere forbindelser på UDP port 213, selvom dette kan 
     ændres. DOSBox opretter automatisk en klient-forbindelse til IPX 
     kanaliseringsserveren når denne er startet.

     Syntaxen for IPXNET STARTSERVER er:
     IPXNET STARTSERVER <port>

     Hvis serveren er bag en router skal UDP port <port> viderestilles til den 
     computer.

     På Linux/Unix-baserede systemer kan port numre lavere end 1023 kun bruges med 
     root privilegier. Brug porte højere end 1023 på disse systemer.

  IPXNET STOPSERVER

     IPXNET STOPSERVER stopper IPX kanaliserings-serveren som er kører på nuværende
     DOSBox. Man bør forsikre sig om at alle andre forbindelser til også er af-
     sluttet, da nedlukning af serveren kan være skyld i lockups/frysninge på andre 
     maskiner som stadig benytter IPX kanaliserings-serveren. 

     Syntax for IPXNET STOPSERVER er: 
     IPXNET STOPSERVER 

  IPXNET PING

     IPXNET PING rundsender en ping forespørgsel på det IPX kanaliserede netværk.
     Til svar vil alle de tilsluttede computere rapportere tiden det tog at sende 
     og modtage ping forespørgslen. 

     Syntaxen for IPXNET PING er: 
     IPXNET PING

  IPXNET STATUS

     IPXNET STATUS, rapporterer status på nuværende DOSBox's IPX kanaliserede 
     netværk. Hvis du vil have en liste over alle computere tilsluttet netværket,
     skal du bruge IPXNET PING kommandoen. 

     Syntaxen for IPXNET STATUS er: 
     IPXNET STATUS 


KEYB [tastaturlayoutkode [kodeside [kodesidefil]]]

  Ændrer tastatur layoutet.Vær venlig at se sektion 8 : "Tastatur Layout", hvis
  du ønsker detaljeret information om tastatur layouts.

  [tastaturlayoutkode] er en streng bestående af fem eller færre bogstaver,
  nogle eksempler er : it141 itl42 (IT) (Italy) eller dk159 (DK) (Danmark). Den 
  specificerer hvilket keyboard/tastatur layout der skal bruges.
  Listen over samtlige DOSBox layouts findes her:
  https://www.vogons.org/viewtopic.php?t=21824


  [kodeside] er nummeret på kodesiden der skal bruges. Keyboard/tastatur layoutet 
  skal give understøttelse for den specificerede kodeside, ellers kan layoutet ikke 
  indlæses. Hvis der ikke er angivet nogen kodeside, bliver der automatisk valgt 
  en passende kodeside for det ønskede layout.

  [kodesidefil] kan bruges til at indlæse kodesider som endnu ikke er indbyggede i 
   DOSBox. Det bruges kun når DOSBox ikke kan finde kodesiden.
   Hvis der ikke er specificeret en kodesidefil, men alle ti ega.cpx filer fra 
   FreeDOS er placeret i DOSBox-program folderen, vælges der en passende 
   kodesidefil for forespurgte layout/kodeside, automatisk.

  Eksempler:
  1) At indlæse et polsk Keyboard/tastatur layout (bruger automatisk kodeside 852):
       keyb pl214
  2) At indlæse et af de russiske Keyboard/tastatur layout med kodeside 866:
       keyb ru441 866
     For at kunne skrive russiske bogstaver tast ALT+HØJRE-SKIFT.
  3) At indlæse det franske Keyboard/tastatur layout med kodeside 850 (hvor kode-
      siden er defineret i filen EGACPI.DAT):
       keyb fr189 850 EGACPI.DAT
  4) At indlæse kodeside 858 (uden keyboard/tastatur layout):
       keyb none 858
     Dette kan bruges til at ændre kodesiden for FreeDos's keyb2 program.
  5) For at vise nuværende kodeside og, hvis indlæst, tastatur layoutet
     keyb (efterfulgt af Enter/Return) 



Hvis du vil vide mere, brug /? efter program/kommandoen.



====================
5. Specielle taster:
====================

ALT-ENTER     Fuldskærm til/fra.
ALT-PAUSE     Pause DOSBox.
CTRL-F1       Starter keymapper.
CTRL-F4       Skifter imellem monterede disk-images. Opdaterer 
              directory-/mappe-/bibliotek-lageret for alle drev!
CTRL-ALT-F5   Starter/Stopper optagelse af film af skærmbillede. (avi video optagelse)
CTRL-F5       Gemmer et skærmbillede. (png type)
CTRL-F6       Starter/Stopper optagelse af lyd til en wave file.
CTRL-ALT-F7   Starter/Stopper optagelse af OPL kommandoer (DRO format).
CTRL-ALT-F8   Starter/Stopper optagelse af rå MIDI kommandoer.
CTRL-F7       Formindske tab af frames/rammer.
CTRL-F8       Forstørre tab af frames/rammer.
CTRL-F9       Afslutte DOSBox.
CTRL-F10      Binde/frigøre musen.
CTRL-F11      Sløve emuléringen (Nedsætte DOSBox Cycles).
CTRL-F12      Sætte mere fart på emuleringen (Øge DOSBox Cycles).*
ALT-F12       Frigøre hastighed (turbo knap).**
F11, ALT-F11  (machine=cga) ændre farvetonen i NTSC mode***
F11           (machine=hercules) bladre igennem farverne : ambra, grøn, hvid***

*NOTAT: Hvis du forøger DOSBox's cycles over din computers maximum ydeevne,
        vil det give samme effekt som at sløve emuleringen.
        Dette maximum vil variere fra computer til computer.

**NOTAT: Du skal have frie resourcer for dette(jo flere du har, jo hurtigere går
         det), så det virker overhovedet ikke med cycles=max eller et for højt 
         sat "fixed cycles". Du skal holde tasterne nedtrykket, for at det 
         virker!

***NOTE: Disse taster virker ikke hvis du tidligere har gemt en mapperfil med en
         anden machine type. Så enten skal du tildele dem igen eller nulstille
         /resette mapper.

Sådan er default tastebindinger. De kan ændres med keymapper
(se Sektion 7:  KeyMapper (Tastatur og joystick indstillinger)).

I MAC OS kan du prøve at bruge cmd (æbletasten) sammen med ctrl hvis tasten ikke
virker f.eks. cmd-ctrl-F1, men nogle taster skal nok stadig "mappes om"
(også i Linux).

Gemte indspillede filer kan findes i:
   (Windows)    "Start/WinLogo Menu"->"All Programs"->"DOSBox-0.74-2"->Extras
   (Linux)      ~/.dosbox/capture
   (MAC OS X)   "~/Library/Preferences/capture"
dette kan ændres i DOSBox's Config-fil. 



====================
6. Joystick/Gamepad:
====================

Dos's Standard Joystick port understøtter et max på 4 akser og 4 knapper.
For flere, blev der brugt forskellige ændringer.

Du kan bruge linien "joysticktype" i [joystick] sektionen i DOSBox's config-fil,
til at ændre type.

none  - slår controleren fra
auto  - (standard) finder automatisk ud af om du har een eller to controlere 
        tilsluttet.
          hvis du har een - bruges '4axis' ,
          hvis du har to - bruges '2axis'.
2axis - Hvis du har 2 controlere sat til, vil de hver især, emulere et joystick
        med 2 akser og 2 knapper. Hvis du kun har een controler sat til, emu-
        léres der et joystick med med 2 akser og 2 knapper.
4axis - Understøtter kun første controler, og emulérer et joystick med 4 akser 
        og 4 knapper, eller et gamepad med 2 akser og 6 knapper.             
4axis_2 -  Understøtter kun anden controler.        
fcs   - Understøtter kun første controler, emulérer ThrustMaster
        Flight Control System, med 3 akser, 4 knapper og en hat.
ch    - Understøtter kun første controler, emulérer CH Flightstick,
        med 4-akser, 6 knapper og en hat, men du kan ikke bruge mere end een 
        knap af gangen.

Du skal også konfiguére controleren rigtigt i selve spillet.

Det er vigtigt at huske, at hvis du gemte mapperfilen uden joysticket tilsluttet,
eller med andre joystick indstillinger, virker de nye indstillinger ikke korrekt,
eller overhovedet ikke før du har nulstillet DOSBox's mapperfil.
  

Hvis controleren virker perfekt udenfor DOSBox, men ikke calibrérer ordentligt i
DOSBox, kan du prøve forskellige 'timed' indstillinger i DOSBox's config-fil.



===============================================
7. Mapper (Tastatur og joystick indstillinger):
===============================================

Når du starter DOSBox mapper (enten med CTRL-F1 eller med -startmapper
som kommandolinieargument) bliver du presenteret for et virtuelt 
keyboard/tastatur og et virtualt joystick.

Disse virtuelle enheder reagere på tasterne/knapperne som DOSBox videresender til
DOS programmer. Hvis du klikker på en tast/knap med din mus, kan du se nederst
i venstre hjørne, hvilken funktion den er bundet til (EVENT) og hvilke funktioner
der lige nu er bundet.

Event: EVENT
BIND: BIND
                        Add   Del
mod1  hold                    Next
mod2
mod3


EVENT
    Tasten eller joystick akse/knap/hat DOSBox videresender til DOS program/spil.
    (den handling som bliver udført i spillet, (f.eks skydning/hop/bevægelse)
BIND
    Knappen på dit fyssike keyboard/tastatur eller akse/knap/hat på dit/dine fy-
    siske joystick(s) (som meddelt af SDL) som er bundet til EVENT(en).
mod1,2,3 
    Modfiers. Dette er taster du skal have nedtrykkede imens du taster BIND. 
    mod1 = CTRL og mod2 = ALT. Disse bliver generelt kun brugt når du ønsker at 
    ændre DOSBox's specielle taster.
Add 
    Tilføjer en ny BIND til denne EVENT. Tilføjer grundlæggende en tast fra dit 
    keyboard/tastatur eller en funktion joysticket (trykket knap, akse/hat bevæ-
    gelse) dette skaber en EVENT(handling) i DOSBox.
Del 
    Sletter denne  EVENT's BIND. Hvis en EVENT ingen BINDS har, er det ikke muligt 
    at udløse den i DOSBox (man kan ikke udløse tasten eller joystick-funktionen).
Next
    Gennemgå listen over bindinger som leder til denne EVENT.


Eksempel:
Q1. Du ønsker at X'et på dit keyboard/tastatur skriver Z i DOSBox.
    A. Klik på Z'et i keyboard mapper. klik "Add". 
       tryk nu x tasten på dit keyboard/tastatur. 

Q2. Hvis du klikker "Next" et par gange, vil du bemærke, at Z'et på dit 
    keyboard/tastatur også laver et Z i DOSBox.
    A. Derfor skal du vælge Z igen, og vælge "Next" til du har Z på dit
    tastatur. Vælg nu "Del".

Q3. Hvis du prøver det i DOSBox, vil du bemærke at når du taster X kommer ZX
    frem.
     A. X'et på dit keyboard/tastatur er også stadig kortlagt til X! Klik på
        X'et i keyboard mapper og søg med "Next" til du finder den kortlagte
        X tast. Klik "Del".


Eksempler på at omprogramere joysticket:
  Du har et joystick tilsluttet, det virker fint i DOSBox og du ønsker at spille
  et kun-for-keyboard/tastatur spil med joysticket (det formodes at spillet
  kontrolleres med piletasterne på keyboardet/tastaturet):
    1) Start mapper, klik så på en af pilene i midten af venstre side af skærmen
       (lige over Mod1/Mod2 knapperne).
       EVENT skal være key_left. Klik nu på Add og flyt dit joystick i samme ret-
       ning(som pilen peger), dette skulle tilføje en handling til BIND.
    2) Gentag ovenstående for de sidste 3 retninger, i tilføjelse kan knapperne
       på joysticket også omprogrameres (fire/jump).
    3) Klik på Save, så på Exit og test det med et spil.

  Hvis du ønsker at ændre y-aksen på joysticket fordi nogle flysimulatorer bruger
  joystickens op/ned  bevægelse på en måde du ikke kan lide, og det ikke kan ind-
  stilles i selve spillet:
    1) Start mapper og klik på Y- i det øvre joystick felt
       EVENT skulle være jaxis_0_1-.
    2) Klik på Del for at fjerne nuværende binding, klik så på Add og flyt dit
       joystick nedad. der skulle nu være  skabt et nyt bind.
    3) Gentag dette for Y+, gem layoutet, og test det til slut i et spil.

  Hvis du ønsker at omprogramere noget med din d-pad/hat er du nødt til ændre
  'joystick=auto' til 'joystick=fcs' i config-filen. Dette bliver måské for-
  bedret i næste DOSBox version.



Hvis du ændrer standard mapping, kan du gemme dine ændringer ved at klikke på
"Save". DOSBox gemmer din mapping til en lokalitet specificeret i config-filen
(mapperfile= linien). DOSBox indlæser din mapper-fil, hvis den er tilstede i
config-filen.



===================
8. Tastatur Layout:
===================

For at skifte til et andet keyboard/tastatur layout, kan bruges enten punktet
"keyboardlayout" i [dos]-sektionen i dosbox.conf, eller det interne DOSBox
program keyb.com. Begge dele accepterer dos-afpassede sprog koder (se nedenunder), 
men du kan kun indlæse en tilpasset sprogkode-fil med keyb.com.

Standard keyboardlayout=auto, som lige nu kun virker under Windows, layoutet
bliver valgt i forhold til OS'ets layout, men tastatur layoutet bliver ikke genkendt.

Skiftning af Layout
  DOSBox understøtter som standard et vist antal keyboard/tastatur layouts  og kode-
  sider,i disse tilfælde er det kun nødvendigt at specificere layoutkoden (som f.eks
  tastaturlayout=dk159 i DOSBox's config-fil, eller "keyb dk159" ved DOSBox's komman-
  doprompt). Listen over alle DOSBox's indbyggede layouts kan findes 
  hér: https://www.vogons.org/viewtopic.php?t=21824
  
  Nogle keyboard/tastatur layouts (f.eks layout GK319 kodeside 869 og layout RU441
  kodeside 808) har understøttelse for dobbelt-layouts, som kan aktiveres med
  tasterne VENSTRE-ALT+HØJRE-SKIFT for et layout og VENSTRE-ALT+VENSTRE-SKIFT for 
  det andet.
  Nogle tastatur layouts (for eksempel LT456 kodeside 771) har understøttelse for
  tre layouts, det tredje kan aktiveres med VENSTRE-ALT+VENSTRE-CTRL.

Understøttede eksterne filer
  FreeDos's .kl filer er understøttet (FreeDos keyb2 tastatur layoutfiler) 
  ligesom FreeDos's keyboard.sys/keybrd2.sys/keybrd3.sys biblioteker som 
  består af alle tilgængelige .kl filer.
  Se på http://www.freedos.org/ for prækompilerede tastatur/keyboard layouts
  hvis de DOSBox-integrerede layouts, af en eller anden grund ikke virker, eller 
  efter opdaterede/nye tilgængelige layouts. 

  Både .CPI (MSDOS/kompatible kodeside filer) og .CPX (FreeDos UPX-komprimerede
  kodeside filer) kan bruges. Nogle kodesider er indbygget i DOSBox så det for 
  det meste ikke er nødvendigt at tænke på kodeside filer. Hvis du har brug for 
  en anden (eller en specielt tilpasset) kodeside fil, kan du kopiere den ind i
  Directoriet/mappen/biblioteket hvor DOSBox config-fil er så DOSBox kan finde den.
  Hvis der ikke er specificeret en kodesidefil, men alle ti ega.cpx filer fra 
  FreeDOS er placeret i DOSBox-program folderen, vælges der en passende 
  kodesidefil for forespurgte layout/kodeside

  Yderligere layouts kan tilføjes ved at kopiere de tilsvarende .kl-filer til
  dosbox.conf's directory/mappe/bibliotek og bruge første del af fil-navnet som
  sprog-kode.
  Eksempel: For filen UZ.KL (keyboard/tastatur layout for Uzbekistan) specificeres
           "keyboardlayout=uz" i DOSBox's config-fil.
  Integreringen af keyboard layout pakker (som keybrd2.sys) virker på samme måde.


Bemærk at keyboard/tastatur layoutet tillader udenlandske karaktérer at 
blive skrevet, men der er ikke understøttelse for dem i filnavne. Prøv at undgå 
dem (tegnene) både i DOSBox og det værts operativ system som er tilgængeligt
fra DOSBox.



==============================
9. Serial Multiplayer feature:
==============================
 
DOSBox kan emulere et serielt nullmodem kabel over netværk og internet.
Dette kan konfigureres i [serialports] sektionen i DOSBox's Config-fil.

For at oprette en nullmodem forbindelse, skal én være server og én klient.

Serveren skal sættes sådan op i DOSBox's config-fil:
   serial1=nullmodem

Klient:
   serial1=nullmodem server:<IP eller navn på serveren>

Start nu spillet og vælg nullmodem / serial cable / already connected
som multiplayer måde på COM1. Set same baudrate på begge computere.

Desuden, kan der tilføjes yderligere parametreametre for at kontrollere opfør-
slen af nullmodem forbindelsen. Dette er alle parametrene:

 * port:         - TCP port nummer. Default: 23
 * rxdelay:      - hvor længe (millisekunder) de modtagne data skal forsinkes hvis
                   enheden ikke er klar. Forøg denne værdi hvis du oplever
                   overrun errors i DOSBox's Status vindue. Standard: 100
 * txdelay:      - hvor længe der skal samles data før der sendes en pakke. 
                   Standard: 12 (reducerer Netværk overhovede)
 * server:       - Dette nullmodem vil være en klient som tilslutter til den spe-
                   cificerede server. (ingen server argument: Vær en server.)
 * transparent:1 - Sender kun de serielle data, ingen RTS/DTR handshake. Bruges
                   når der tilsluttes til alt andet end et nullmodem.
 * telnet:1      - Oversætter Telnet data fra et andet sted(tilsluttet). Sætter
                   automatisk transparent.
 * usedtr:1      - Forbindelsen bliver ikke lavet før DTR bliver slået til af
                   DOS programmet. Bruges med modem terminaler.
                   Sætter automatisk transparent.
 * inhsocket:1   - Brug en socket sendt til DOSBox ad kommandolinien. Sætter
                   automatisk transparent. (Socket Inheritance: Det bruges til at 
                   spille gamle DOS door games på ny BBS software.)

Eksempel: Vær en server der lytter på TCP port 5000.
   serial1=nullmodem server:<IP eller navn på serveren> port:5000 rxdelay:1000



===========================================
10.Hvordan du ændrer hastigheden på DOSBox: 
===========================================

DOSBox emulerer CPUen, lyd- og grafik- kort , og andre dele af PCen, det hele
på samme tid. Hastigheden på den emulerede DOS applikation afhænger af hvor
mange instruktioner der kan emuleres, kan justeres (antal cycles).

CPU Cycles
  Standard prøver DOSBox (cycles=auto) at detektere om et spil har brug for, at 
  blive kørt med så mange instruktioner emuleret per tids-interval som muligt 
  (cycles=max, får til tider et spil til at køre for hurtigt eller ustabilt),
  eller om der skal bruges et fikséret antal cycles (cycles=3000 , får til tider 
  spillet til at arbejde for langsomt eller for hurtigt). Men du kan altid, 
  manuelt, indføre en anden indstilliong i DOSBox's config-fil.

  Man kan tvinge langsom eller hurtig opførsel igennem ved at sætte et fikséret antal
  cycles i DOSBox's config-fil. Hvis du f.eks. sætter cycles=10000 viser DOSBox 
  øverst en linie "Cpu Speed: fixed 10000 cycles" . I dette modus kan du reducere
  antal cycles endnu mere med tasterne CTRL-F11 (så lavt som du ønsker), eller hæve 
  antal cycles med tasterne CTRL-F12, så meget som du ønsker (dog begrænset af een 
  kerne's styrke i din computers CPU). Du kan se hvor meget fritid din rigtige CPU's 
  kerner har i Taskmanager i Windows 2000/XP/VISTA/ og System Monitor i Windows 
  95/98/ME. Når du har brugt 100% af din rigtige CPU's ene kerne's styrke, er der ikke
  videre mulighed for at hæve hastigheden på DOSBox (DOSBox begynder faktisk at ar-
  bejde langsommere), undtagen hvis du mindsker belastningen på ikke-cpu delene af 
  DOSBox. DOSBox kan kun bruge een CPU-kerne, så hvis du har en CPU med f.eks. 4 
  kerner, kan DOSBox ikke bruge de andre 3 kerner.
 
  Man kan tvinge hurtig opførsel igennem ved at sætte cycles=max i DOSBox's config-
  fil. DOSBox's vindue viser i så fald linien "Cpu Speed: max 100% cycles", øverst. 
  I denne tilstand behøver du ikke bekymre dig over hvor meget fritid din rigtige 
  CPU har, for DOSBox vil altid bruge 100% af din rigtige CPU's ene kerne. I dette
  modus kan du aflaste din rigtige CPU med tasterne CTRL-F11, eller øge belastningen
  igen med CTRL-F12.

CPU Kerner(Cores)
  På x86 arkitekturer kan du prøve at tvinge brugen af "dynamisk genindsamlings 
  kerne" (sæt core=dynamic i DOSBox's config-fil).
  Dette giver normalt bedre resultater, hvis auto genkendeklsen (core=auto) fejler.
  Indstillingen fungerer bedst sammen med cycles=max. Men du kan ogdå prøve sammen 
  med et højt antal cycles (f.eks. 20000 eller mere).Der kan dog være spil som 
  virker dårligere med "dynamisk genindsamlings kerne" indstillingen (gém dit 
  spil ofte), eller slet ikke!.

Grafik emulering (hæve hastigheden)
  VGA emulering er en meget krævende del af DOSBox's reelle CPU forbrug. Du kan 
  forstørre tabet af antal rammer/frames der skippes (forøges med antallet et) ved
  at nedtrykke tasterne CTRL-F8. Dit CPU forbrug skulle formindskes når du bruger
  en fast "cycles" indstilling, og du kan hæve antallet af cycles med CTRL-F12.
  Dette kan du gøre til spillet kører hurtigt nok.
  Læg dog mærke til at dette er et kompromis : du mister tilsvarende kvalitet i 
  billede som du vinder hastighed.

Lyd emulering (hæve hastigheden)
  Du kan også prøve at slå lyden fra i spillets setup program for at reducere
  CPU forbruget yderligere. indstillingen nosound=true i DOSBox's config-fil slår
  IKKE emuleringen af lydenheder fra, det er kun lyd-outputet der bliver slået fra.

Prøv også at lukke alle andre programmer for at reservere så mange resourcer som
muligt til DOSBox.


Avanceret cycles indstillinger:
Cycles=auto og cycles=max indstillingerne kan sættes med andre parametre 
for forskellige start standarder. Syntaksen er
  cycles=auto ["realmode default"] ["protected mode default"%] 
              [limit "cycles begrænsning"]
  cycles=max ["protected mode default"%] [limit "cycles begrænsning"]
Eksempel:
  cycles=auto 1000 80% limit 20000
  bruger cycles=1000 for real mode spil, 80% cpu effekt for 
  protected mode spil sammen med en hård cycle begrænsning på 20000



====================
11. Problemløsning:
====================

Generel tip:
  Tjek meddelelser i DOSBox's Statusvindue. Se sektion 12 "DOSBox's statusvindue"  


DOSBox dør lige efter start:
  - brug andre værdier i output= indstillingen i din DOSBox
    config-fil
  - prøv at opdatere grafikkort-driver og DirectX
  - (Linux) sæt miljøvariablen SDL_AUDIODRIVER til alsa eller oss.

Når du kører et bestemt spil lukker DOSBox, med en/flere besked(er) eller hænger:
  - se om det virker med Standard DOSBox installation
    (uændret config-fil)
  - prøv uden lyd (brug det lydindstillingsprogram som er med spillet, endvidere
    kan du prøve sbtype=none og gus=false)
  - lav om på nogle af indstillingerne i DOSBox's config-fil, prøv specielt :
      core=normal
      faste cycles (for eksempel cycles=10000)
      ems=false
      xms=false
    eller en kombination af ovenstående
    machine indstilling der har samme chipset og funktion
    funktionsmæssigt:
      machine=vesa_nolfb
    eller
      machine=vgaonly
  - brug loadfix før du starter spillet 

Spillet går tilbage til DOSBox's kommandoprompt med fejlmeddelelse:
  - læs fejlmeddelelsen koncentreret og prøv at lokalisere fejlen
  - prøv tipsene i ovennævnte sektioner
  - monter anderledes da nogle spil er fintfølende med lokaliteterne,
    prøv for eksempel hvis du har monteret d d:\Gamlespil\spil"
    "mount c d:\Gamlespil\spil" istedet "mount c d:\Gamlespil"
  - hvis spillet kræver cdrom, vær sikker på at du skrev "-t cdrom" da du
    monterede og prøv forskellige andre yderligere parametre (ioctl, usecd og label
    switchene, se den rette sektion)
  - Tjek filerne til spillet's tilladelser (fjern read-only attributter,
    tilføj skrivetilladelser og lignende.)
  - prøv at geninstallere spillet i selve DOSBox



=========================
12. DOSBox Status Window:
=========================

DOSBox's Statusvindue indeholder meget nyttig information om dine nuværende ind-
stillinger, hvad du gør i DOSBox, fejl der opstår og meget mere. 
Tjek disse meddelelser, når du oplever fejl.

Hvordan du starter DOSBox's Statusvindue:
  (Windows)  Statusvinduet starter sammen med Hoved-DOSBox-vinduet.
  (Linux)    Det kan være nødvendigt at starte DOSBox fra Konsollen, for at få
             et Statusvindue.
  (MAC OS X) Højreklik på DOSBox.app, vælg "Show Package Contents" ->
             ->enter "Contents"->enter "MACOS"->run "DOSBox"



=====================================
13. Config-filen (indstillingsfilen):
=====================================

config-filen genereres automatisk første gang du starter DOSBox.
Filen kan findes i: (engelsk, den danske skal (som standard) være i DOSBox's 0.74 
mappen, i de fleste tilfælde "c:\programmer\DOSBox-0.74", lav selv en genvej til
dosbox.conf i startmenuen)
   (Windows)  "Start/WinLogo Menu"->"All Programs"->"DOSBox-0.74-2"->Options
   (Linux)    ~/.dosbox/dosbox-0.74-2.conf
   (MAC OS X) "~/Library/Preferences/DOSBox 0.74-2 Preferences"
Filen er indelt i adskillige sektioner. Hver sektion starter med en
[sektion navn] linie. Indstillingerne er beskrivelse=værdi linier hvor værdi kan 
ændres for tilpasse DOSBox.
# og % viser komentarlinier


Der kan genereres en config-fil med CONFIG.COM, som kan findes på det interne
DOSBox Z: drev hvor du starter DOSBox. Se i sektione 4 :"interne programmer"
af denne readme hvordan du bruger CONFIG.COM. Du kan tilpasse den genererede 
config-fil til dit DOSBox behov. Du kan starte DOSBox med -conf "config-fil"
switchen og indlæse den generérede fil og dens indstillinger

DOSBox bruger config-filer der er angivet med -conf. Hvis der ikke er
angivet en fil, søges efter "dosbox.conf" i det lokale directory/mappe/bibliotek.
Hvis der ingen er, vil DOSBox hente brugerens config-fil. 
Denne fil bliver skabt, hvis den ikke allerede eksisterer

Vigtigt!: I Windows Vista/7 virker konfigurationsfilen ikke som den skal hvis
den er placeret i "Windows" eller "Program Files" i een af deres under-mapper,
eller direkte på c:\, så den bedste placering for ekstra konfig-filer er for
eksempel c:\oldgames



================
14. Sprog-filen:
================


Der kan genereres en Sprog-fil med CONFIG.COM , som kan findes på det interne Z: 
drev, når du starter DOSBox. Se i Sektion 4:"Interne programmer", hvordan man bruger 
config.com 
Læs den, så forstår du forhåbentligt hvordan man ændrer den. 
Start med DOSBox -lang "sprog-fil" switchen og indlæs din sprog-fil.
Du kan alternativt indføre filenavnet i config-filen i [dosbox] Sektionen. 
Der er en language= indstilling der kan ændres med et filnavn.



=================================================
15. Hvordan du bygger din egen version af DOSBox:
=================================================


Hent/Download kildefilerne (source).
Læs INSTALL i  kilde-distributionen.



===================
14. Special thanks:
===================


Se THANKS filen.



============
15. Kontakt:
============

See the site: 
https://www.dosbox.com
for an email address (The Crew-page).
(email adresse på : https://www.dosbox.com  The Crew-siden)



